@@ -1,9 +1,8 @@
-#pragma once
 /* -copyright-
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021 Willem Vermin
+#-# 	      2019,2020,2021,2022 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -19,17 +18,12 @@
 #-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #-# 
  */
-#include "xsnow.h"
+#pragma once
+
+#include <gtk/gtk.h>
+
 extern int    Santa_draw(cairo_t *cr);
-extern void   Santa_HandleCpuFactor(void);
+extern void   Santa_erase(cairo_t *cr);
 extern void   Santa_init(void);
-extern void   Santa_set_gc(void);
 extern void   Santa_ui(void);
 
-extern float  ActualSantaSpeed;
-extern Region SantaPlowRegion;
-extern int    SantaHeight;
-extern int    SantaWidth;
-extern int    SantaX;
-extern int    SantaY;
-
