@@ -2,7 +2,7 @@
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021 Willem Vermin
+#-# 	      2019,2020,2021,2022 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 
 #include <X11/Xlib.h>
 #include "doit.h"
+#include "safe_malloc.h"
 
 #define UIDO(_x,_y) \
    if(Flags._x != OldFlags._x) \
