@@ -2,7 +2,7 @@
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021 Willem Vermin
+#-# 	      2019,2020,2021,2022 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -25,6 +25,8 @@
 #include "ixpm.h"
 #include "debug.h"
 #include "utils.h"
+#include "safe_malloc.h"
+
 // from the xpm package:
 static void xpmCreatePixmapFromImage(
       Display	*display,
@@ -122,7 +124,7 @@ int iXpmCreatePixmapFromData(Display *display, Drawable d,
 	    printf("XpmFileInvalid\n");
 	    break;
 	 case -3:
-	    printf("XpmNoMemory\n");
+	    printf("XpmNoMemory: maybe issue with width of data: w=%d\n",w);
 	    break;
 	 case -4:
 	    printf("XpmColorFailed\n");
@@ -134,6 +136,7 @@ int iXpmCreatePixmapFromData(Display *display, Drawable d,
 	    break;
       }
       printf("exiting\n");
+      fflush(NULL);
       abort();
    }
    XAddPixel(ximage,0xff000000);
@@ -149,8 +152,9 @@ int iXpmCreatePixmapFromData(Display *display, Drawable d,
 }
 
 // given xpmdata **data, add the non-transparent pixels to Region r
-Region regionfromxpm(const char **data, int flop)
+Region regionfromxpm(const char **data, int flop, float scale)
 {
+   (void) scale;   // todo gdk_cairo_region_create_from_surface kan worden gebruikt
    int w,h,nc,n;
    Region r = XCreateRegion();
    // width, height, #colors, $chars to code color
@@ -161,7 +165,7 @@ Region regionfromxpm(const char **data, int flop)
    int offset = nc + 1;
    for(i=1; i<=nc; i++)
    {
-      char s[100];
+      char s[101];
       P("%s\n",data[i]);
       sscanf(data[i]+n,"%*s %100s",s);
       P("%s\n",s);
@@ -196,6 +200,35 @@ Region regionfromxpm(const char **data, int flop)
    return r;
 }
 
+cairo_region_t *gregionfromxpm(const char **data, int flop, float scale)
+{
+   int w,h;
+   sscanf(data[0],"%d %d",&w,&h);
+   P("gregionfromxpm: w:%d h:%d\n",w,h);
+
+   GdkPixbuf *pixbuf;
+   GdkPixbuf *pixbuf1 = gdk_pixbuf_new_from_xpm_data(data);
+   if (flop)
+   {
+      pixbuf = gdk_pixbuf_flip(pixbuf1,1);
+      g_clear_object(&pixbuf1);
+   }
+   else
+      pixbuf = pixbuf1;
+
+   int iw = w*scale; if(iw < 1) iw = 1;
+   int ih = h*scale; if(ih < 1) ih = 1;
+   if (iw == 1 && ih == 1) ih = 2;
+   GdkPixbuf *pixbufscaled  = gdk_pixbuf_scale_simple(pixbuf,iw,ih,GDK_INTERP_HYPER);
+   cairo_surface_t *surface = gdk_cairo_surface_create_from_pixbuf (pixbufscaled, 0, NULL);
+   g_clear_object(&pixbuf);
+   g_clear_object(&pixbufscaled);
+
+   cairo_region_t *region = gdk_cairo_region_create_from_surface(surface);
+   cairo_surface_destroy(surface);
+   return region;
+}
+
 /*
  * converts xpm data to bitmap
  * xpm:        input xpm data
@@ -211,7 +244,8 @@ int xpmtobits(char *xpm[],unsigned char **bitsreturn, int *wreturn, int *hreturn
 {
    int nc,cpp,w,h;
 
-   unsigned char *bits = (unsigned char*) malloc(sizeof(unsigned char)*1);
+   //unsigned char *bits = (unsigned char*) malloc(sizeof(unsigned char)*1);
+   unsigned char *bits = NULL;
    if (sscanf(xpm[0],"%d %d %d %d",&w,&h,&nc,&cpp)!=4)
       return 0;
    if(cpp <=0 || w<0 || h<0 || nc<0)
@@ -222,6 +256,7 @@ int xpmtobits(char *xpm[],unsigned char **bitsreturn, int *wreturn, int *hreturn
    *lreturn = l*h;
    // l*h+1: we do not want allocate 0 bytes
    bits = (unsigned char*) realloc(bits,sizeof(unsigned char)*(l*h+1));
+   REALLOC_CHECK(bits);
    *bitsreturn = bits;
    int i;
    for(i=0; i<l*h; i++)
@@ -234,7 +269,7 @@ int xpmtobits(char *xpm[],unsigned char **bitsreturn, int *wreturn, int *hreturn
    int offset = nc + 1;
    for(i=1; i<=nc; i++)
    {
-      char s[100];
+      char s[101];
       if (strlen(xpm[i]) > (size_t)cpp + 6)
       {
 	 sscanf(xpm[i]+cpp,"%*s %100s",s);
@@ -317,7 +352,7 @@ int xpmtobits(char *xpm[],unsigned char **bitsreturn, int *wreturn, int *hreturn
 //};
 // change the second color to color and put the result in out.
 // lines will become the number of lines in out, comes in handy
-// when wanteing to free out.
+// when wanting to free out.
 void xpm_set_color(char **data, char ***out, int *lines, const char *color)
 {
    int n;  
@@ -328,8 +363,8 @@ void xpm_set_color(char **data, char ***out, int *lines, const char *color)
    int j;
    for (j=0; j<2; j++)
       x[j] = strdup(data[j]);
-   x[2] = (char *)malloc(5+sizeof(color));
-   x[2][0] = 0;
+   x[2] = (char *)malloc(5+strlen(color));
+   x[2][0] = '\0';
    strcat(x[2],". c ");
    strcat(x[2],color);
    P("c: [%s]\n",x[2]);
