@@ -2,7 +2,7 @@
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021 Willem Vermin
+#-# 	      2019,2020,2021,2022 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -46,6 +46,7 @@
    */
 /* single nearest neighbor search written by Tamas Nepusz <tamas@cs.rhul.ac.uk> */
 
+#include <pthread.h>
 #define USE_LIST_NODE_ALLOCATOR
 #define NO_ALLOCA
 
@@ -64,6 +65,7 @@
 #include <math.h>
 #include <assert.h>
 #include "kdtree.h"
+#include "safe_malloc.h"
 
 #if defined(WIN32) || defined(__WIN32__)
 #include <malloc.h>
