@@ -2,7 +2,7 @@
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020 Willem Vermin
+#-# 	      2019,2020,2021,2022 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
 #-# 
 */
 
+#include <pthread.h>
 #include "xsnow.h"
 #include "snow.h"
 #include "pixmaps.h"
@@ -173,6 +174,11 @@ XPM_TYPE **birds_xpm[] =
    birdd1_xpm, birdd2_xpm, birdd3_xpm, birdd4_xpm, birdd5_xpm, birdd6_xpm, birdd7_xpm, birdd8_xpm
 };
 
+#include "Pixmaps/moon1.xpm"
+XPM_TYPE **moons_xpm[]=
+{
+   moon1_xpm
+};
 
 #define SNOW(x) snow##x##_xpm,
 XPM_TYPE **snow_xpm[] =
@@ -188,4 +194,4 @@ XPM_TYPE **snow_xpm[] =
  *    NULL
  * }
  * */
-#undef SNOW
+#include "undefall.inc"
