@@ -2,7 +2,7 @@
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021 Willem Vermin
+#-# 	      2019,2020,2021,2022 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -20,26 +20,13 @@
 */
 #pragma once
 
-#include <X11/Intrinsic.h>
+#include <gtk/gtk.h>
 
 #define STARANIMATIONS 4
 
-typedef struct _StarMap {
-   unsigned char *starBits;
-   Pixmap pixmap;
-   int width;
-   int height;
-} StarMap;
-
-typedef struct _Skoordinaten {
-   int x; 
-   int y; 
-   int color; 
-} Skoordinaten;
-
-extern void    init_stars(void);
-extern void    stars_draw(cairo_t *cr);
-extern void    stars_init(void);
-extern void    stars_set_gc(void);
-extern void    stars_ui(void);
+extern void init_stars(void);
+extern void stars_draw(cairo_t *cr);
+extern void stars_erase(void);
+extern void stars_init(void);
+extern void stars_ui(void);
 
