@@ -2,7 +2,7 @@
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021 Willem Vermin
+#-# 	      2019,2020,2021,2022 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -19,14 +19,12 @@
 #-# 
   */
 
-extern Region          SnowOnTreesRegion;
-extern cairo_region_t *gSnowOnTreesRegion;
-extern XPoint         *SnowOnTrees;
-extern int             OnTrees;
+#pragma once
 
-extern void            treesnow_set_gc(void);
-extern void            reinit_treesnow_region(void);
-extern void            InitSnowOnTrees(void);
-extern void            treesnow_init(void);
-extern void            treesnow_draw(cairo_t *cr);
-extern void            treesnow_ui(void);
+#include <gtk/gtk.h>
+
+extern void reinit_treesnow_region(void);
+extern void InitSnowOnTrees(void);
+extern void treesnow_init(void);
+extern void treesnow_draw(cairo_t *cr);
+extern void treesnow_ui(void);
