@@ -2,7 +2,7 @@
 #-# 
 #-# xsnow: let it snow on your desktop
 #-# Copyright (C) 1984,1988,1990,1993-1995,2000-2001 Rick Jansen
-#-# 	      2019,2020,2021 Willem Vermin
+#-# 	      2019,2020,2021,2022 Willem Vermin
 #-# 
 #-# This program is free software: you can redistribute it and/or modify
 #-# it under the terms of the GNU General Public License as published by
@@ -44,3 +44,5 @@ extern int   ui_checkgtk(void);
 extern char *ui_gtk_version(void);
 extern char *ui_gtk_required(void);
 extern int   ui_run_nomenu(void);
+
+extern void set_buttons(void);
