@@ -24,6 +24,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <X11/Intrinsic.h>
+#include <X11/extensions/Xinerama.h>
 #include <ctype.h>
 //#include <byteswap.h>
 #include "debug.h"
@@ -36,6 +37,7 @@
 #include "transwindow.h"
 #include "dsimple.h"
 #include "safe_malloc.h"
+#include "xdo.h"
 
 #include "vroot.h"
 static int    do_sendevent(void *);
@@ -44,6 +46,7 @@ static long   TransWorkSpace = -SOMENUMBER;  // workspace on which transparent w
 static WinInfo      *Windows = NULL;
 static int          NWindows;
 static int          do_wupdate(void *);
+static void         DetermineVisualWorkspaces(void);
 
 void windows_ui()
 {
@@ -64,7 +67,10 @@ void DestroyWindow(Window w)
 void windows_init()
 {
    if (global.Desktop)
+   {
+      DetermineVisualWorkspaces();
       add_to_mainloop(PRIORITY_DEFAULT, time_wupdate, do_wupdate);
+   }
    if (!global.IsDouble)
       add_to_mainloop(PRIORITY_DEFAULT, time_sendevent, do_sendevent);
 }
@@ -74,7 +80,15 @@ int WorkspaceActive()
    P("global.Trans etc %d %d %d %d\n",Flags.AllWorkspaces,global.Trans,global.CWorkSpace == TransWorkSpace,
 	 Flags.AllWorkspaces || !global.Trans || global.CWorkSpace == TransWorkSpace);
    // ah, so difficult ...
-   return Flags.AllWorkspaces || !global.Trans || global.CWorkSpace == TransWorkSpace;
+   if (Flags.AllWorkspaces)
+      return 1;
+   int i;
+   for (i=0; i<global.NVisWorkSpaces; i++)
+   {
+      if (global.VisWorkSpaces[i] == global.ChosenWorkSpace)
+	 return 1;
+   }
+   return 0;
 }
 
 int do_sendevent(void *dummy)
@@ -104,6 +118,7 @@ void UpdateWindows()
 
 int do_wupdate(void *dummy)
 {
+   static long PrevWorkSpace = -123;
    P("do_wupdate %d %d\n",counter++,global.WindowsChanged);
    if (Flags.Done)
       return FALSE;
@@ -134,7 +149,15 @@ int do_wupdate(void *dummy)
    long r;
    r = GetCurrentWorkspace();
    if(r>=0) 
+   {
       global.CWorkSpace = r;
+      if (r != PrevWorkSpace)
+      {
+	 P("workspace changed from %ld to %ld\n",PrevWorkSpace,r);
+	 PrevWorkSpace = r;
+	 DetermineVisualWorkspaces();
+      }
+   }
    else
    {
       I("Cannot get current workspace\n");
@@ -142,7 +165,6 @@ int do_wupdate(void *dummy)
       goto end;
    }
 
-
    P("Update windows\n");
 
    if(Windows) free(Windows);
@@ -166,8 +188,16 @@ int do_wupdate(void *dummy)
       goto end;
    }
 
-   //P("%d:\n",counter++);printwindows(display,Windows,NWindows);
-   //P("%d:\n",counter++);PrintFallenSnow(global.FsnowFirst);
+   int i;
+   for (i=0; i<NWindows; i++)
+   {
+      WinInfo *w = &Windows[i];
+      P("SnowWinX SnowWinY: %d %d\n",global.SnowWinX,global.SnowWinY);
+      w->x += global.WindowOffsetX-global.SnowWinX;
+      w->y += global.WindowOffsetY-global.SnowWinY;
+   }
+
+
    // Take care of the situation that the transparent window changes from workspace, 
    // which can happen if in a dynamic number of workspaces environment
    // a workspace is emptied.
@@ -187,7 +217,7 @@ int do_wupdate(void *dummy)
       {
 	 TransWorkSpace = winfo->ws;
       }
-      P("TransWorkSpace %#lx %#lx %#lx %#lx\n",TransWorkSpace,winfo->ws,global.SnowWin,GetCurrentWorkspace());
+      P("TransWorkSpace %ld %#lx %#lx %ld\n",TransWorkSpace,winfo->ws,global.SnowWin,GetCurrentWorkspace());
    }
 
    P("do_wupdate: %d %p\n",global.Trans,(void *)winfo);
@@ -207,6 +237,126 @@ end:
    (void)dummy;
 }
 
+void DetermineVisualWorkspaces()
+{
+   P("%d Entering DetermineVisualWorkspaces\n",global.counter++);
+   static Window ProbeWindow = 0;
+   static XClassHint class_hints;
+   static XSetWindowAttributes attr;
+   static long valuemask;
+   static long hints[5] = {2 , 0, 0, 0, 0};
+   static Atom motif_hints;
+   static XSizeHints wmsize;
+
+   if (!global.Desktop)
+   {
+      global.NVisWorkSpaces   = 1;
+      global.VisWorkSpaces[0] = global.CWorkSpace;
+      return;
+   }
+
+   if (ProbeWindow)
+   {
+      XDestroyWindow(global.display, ProbeWindow);
+   }
+   else
+   {
+      P("Creating attrs for ProbeWindow\n");
+      attr.background_pixel = WhitePixel(global.display, global.Screen);
+      attr.border_pixel     = WhitePixel(global.display, global.Screen);
+      attr.event_mask       = ButtonPressMask;
+      valuemask             = CWBackPixel | CWBorderPixel | CWEventMask;
+      class_hints.res_name  = (char *)"xsnow";
+      class_hints.res_class = (char *)"Xsnow";
+      motif_hints = XInternAtom(global.display, "_MOTIF_WM_HINTS", False);
+      wmsize.flags = USPosition | USSize;
+   }
+
+   int number;
+   XineramaScreenInfo *info = XineramaQueryScreens(global.display,&number);
+   if (number == 1 || info == NULL)
+   {
+      global.NVisWorkSpaces = 1;
+      global.VisWorkSpaces[0] = global.CWorkSpace;
+      return;
+   }
+
+
+   // This is for bspwm and possibly other tiling window magagers.
+   //
+   // Determine which workspaces are visible: place a window (ProbeWindow)
+   // in each xinerama screen, and ask in which workspace the window
+   // is located.
+
+   //int prevsticky = set_sticky(1);
+
+   ProbeWindow = XCreateWindow (global.display, global.Rootwindow,
+	 1,1,1,1,10,
+	 DefaultDepth(global.display, global.Screen), InputOutput,
+	 DefaultVisual(global.display, global.Screen),valuemask,&attr);
+   XSetClassHint(global.display,ProbeWindow,&class_hints);
+
+   // to prevent the user to determine the intial position (in twm for example)
+   XSetWMNormalHints(global.display, ProbeWindow, &wmsize);
+
+   XChangeProperty(global.display, ProbeWindow, motif_hints, motif_hints, 
+	 32, PropModeReplace, (unsigned char *)&hints, 5);
+   xdo_map_window(global.xdo,ProbeWindow);
+
+   global.NVisWorkSpaces = number;
+   int i;
+   int prev = -SOMENUMBER;
+   for (i=0; i<number; i++)
+   {
+      int x = info[i].x_org;
+      int y = info[i].y_org;
+      int w = info[i].width;
+      int h = info[i].height;
+
+      // place ProbeWindow in the center of xinerama screen[i]
+
+      int xm = x+w/2;
+      int ym = y+h/2;
+      P("movewindow: %d %d\n",xm,ym);
+      xdo_move_window(global.xdo,ProbeWindow,xm,ym);
+      xdo_wait_for_window_map_state(global.xdo,ProbeWindow,IsViewable);
+      long desktop;
+      int rc = xdo_get_desktop_for_window(global.xdo,ProbeWindow,&desktop);
+      if (rc == XDO_ERROR)
+	 desktop = global.CWorkSpace;
+      P("desktop: %ld rc: %d\n",desktop,rc);
+      global.VisWorkSpaces[i] = desktop;
+
+      if (desktop != prev)
+      {
+	 // this is for the case that the xinerama screens belong to different workspaces,
+	 // as seems to be the case in e.g. bspwm
+	 if (prev >= 0)
+	 {
+	    global.WindowOffsetX = 0;
+	    global.WindowOffsetY = 0;
+	 }
+	 prev = desktop;
+      }
+   }
+   xdo_unmap_window(global.xdo,ProbeWindow);
+}
+
+int IsVisibleWindow(Window wid) // not used
+{
+   long desktop;
+   xdo_get_desktop_for_window(global.xdo,wid,&desktop); // todo replace with existsing window list
+   int i;
+   for (i=0; i<global.NVisWorkSpaces; i++)
+   {
+      P("examining %d %ld %ld\n",i,desktop,global.VisWorkSpaces[i]);
+      if (global.VisWorkSpaces[i] == desktop)
+	 return 1;
+   }
+   P("desktop not visible %ld\n",desktop);
+   return 0;
+}
+
 void UpdateFallenSnowRegionsWithLock()
 {
    Lock_fallen();
@@ -286,7 +436,7 @@ void UpdateFallenSnowRegions()
 	       || ( w->w > 0.8*global.SnowWinWidth 
 		  && w->ya < Flags.IgnoreTop)                           // too wide&too close to top   
 	       || ( w->w > 0.8*global.SnowWinWidth 
-		  && global.SnowWinHeight - w->ya < Flags.IgnoreBottom) // too wide&too close to bottom
+		  && (int)global.SnowWinHeight - w->ya < Flags.IgnoreBottom) // too wide&too close to bottom
 	   )
 	 {
 	    GenerateFlakesFromFallen(fsnow,0,fsnow->w,-10.0);
@@ -324,7 +474,6 @@ void UpdateFallenSnowRegions()
 	       P("CleanFallenArea\n");
 	       fsnow->x = w->x + Flags.OffsetX;
 	       fsnow->y = w->y + Flags.OffsetY;
-	       //DrawFallen(fsnow);
 	       XFlush(global.display);
 	    }
 	 }
@@ -444,20 +593,6 @@ int DetermineWindow(Window *xwin, char **xwinname, GtkWidget **gtkwin, const cha
 	    &x, &y, &w, &h, &b, &depth);
       P("geom: %d %d %d %d\n",x,y,w,h);
       printf("Force snow on root: window: %#lx, depth: %d\n",*xwin,depth);
-      if(0) // Trying to couple the virtual root window to gtk/cairo. No success ...
-      {
-	 GdkWindow *gdkwin;
-	 GdkDisplay *gdkdisplay;
-	 gdkdisplay = gdk_display_get_default();
-	 P("display: %p gdkdisplay: %p\n",(void*)global.display,(void*)gdkdisplay);
-	 gdkwin = gdk_x11_window_foreign_new_for_display(gdkdisplay,*xwin);
-	 *gtkwin = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-	 //gtk_window_set_screen(GTK_WINDOW(*gtkwin),gdk_window_get_screen(gdkwin));
-	 gtk_widget_set_window(*gtkwin,gdkwin);
-	 gtk_widget_show_all(*gtkwin);
-	 gdk_window_show(gdkwin);
-	 *IsDesktop = 1;
-      }
    }
    else
    {
@@ -479,17 +614,18 @@ int DetermineWindow(Window *xwin, char **xwinname, GtkWidget **gtkwin, const cha
 
       *gtkwin = gtk_window_new        (GTK_WINDOW_TOPLEVEL); 
 
-      int rc = make_trans_window(*gtkwin,
-	    1,                   // full screen 
+      int wantx, wanty;
+      int rc = make_trans_window(global.display,*gtkwin,
+	    -1,                  // full screen 
 	    Flags.AllWorkspaces, // sticky 
 	    Flags.BelowAll,      // below
 	    1,                   // dock
 	    NULL,                // gdk_window
-	    xwin                 // x11_window
+	    xwin,                // x11_window
+	    &wantx,
+	    &wanty
 	    );
       gtk_window_set_title(GTK_WINDOW(*gtkwin), transname);
-      //int rc = create_transparent_window(Flags.AllWorkspaces, Flags.BelowAll, 
-      //	    xwin, transname, *gtkwin, w, h);
 
       if (!rc)
       {
@@ -589,6 +725,7 @@ int DetermineWindow(Window *xwin, char **xwinname, GtkWidget **gtkwin, const cha
 
 
 Window XWinInfo(char **name)
+   // not used
 {
    Window win = Select_Window(global.display,1);
    if(name)
@@ -604,18 +741,79 @@ Window XWinInfo(char **name)
    return win;
 }
 
+// gets location and size of xinerama screen xscreen, -1: full screen
+// returns the number of xinerama screens
+int xinerama(Display *display, int xscreen, int *x, int *y, int *w, int *h)
+{
+   int number;
+   XineramaScreenInfo *info = XineramaQueryScreens(display,&number);
+   if (info == NULL)
+   {
+      I("No xinerama...\n");
+      return FALSE;
+   }
+   else
+   {
+      int scr = xscreen;
+      if(scr > number-1)
+	 scr = number-1;
+
+      int i;
+      for (i=0; i<number; i++)
+      {
+	 P("number: %d\n",info[i].screen_number);
+	 P("   x_org:  %d\n",info[i].x_org);
+	 P("   y_org:  %d\n",info[i].y_org);
+	 P("   width:  %d\n",info[i].width);
+	 P("   height: %d\n",info[i].height);
+      }
+
+      if (scr < 0)
+      {
+	 // set x,y to 0,0
+	 // set width and height to maximum values found
+	 int i;
+	 *x = 0;
+	 *y = 0;
+	 *w = 0;
+	 *h = 0;
+	 for (i=0; i<number; i++)
+	 {
+	    if (info[i].width > *w)
+	       *w = info[i].width;
+	    if (info[i].height > *h)
+	       *h = info[i].height;
+	 }
+      }
+      else
+      {
+
+	 *x = info[scr].x_org;
+	 *y = info[scr].y_org;
+	 *w = info[scr].width;
+	 *h = info[scr].height;
+      }
+      P("Xinerama window: %d+%d %dx%d\n",*x,*y,*w,*h);
+
+      XFree(info);
+   }
+   return number;
+}
+
 void InitDisplayDimensions()
 {
-   unsigned int wroot,hroot,broot,droot;
-   int xroot,yroot;
-   Window root;
-   XGetGeometry(global.display,global.Rootwindow,&root,
-	 &xroot, &yroot, &wroot, &hroot, &broot, &droot);
-   global.Xroot = xroot;
-   global.Yroot = yroot;
-   global.Wroot = wroot;
-   global.Hroot = hroot;
-   P("InitDisplayDimensions: %p %d %d %d %d %d %d\n",(void*)global.Rootwindow,xroot,yroot,wroot,hroot,broot,droot);
+   unsigned int w,h;
+   int x,y;
+   xdo_get_window_location(global.xdo, global.Rootwindow, &x, &y,NULL);
+   xdo_get_window_size    (global.xdo, global.Rootwindow, &w, &h);
+
+   P("InitDisplayDimensions root: %p %d %d %d %d\n",(void*)global.Rootwindow,x,y,w,h);
+
+   global.Xroot = x;
+   global.Yroot = y;
+   global.Wroot = w;
+   global.Hroot = h;
+
    DisplayDimensions();
 }
 
@@ -624,10 +822,13 @@ void DisplayDimensions()
    P("Displaydimensions\n");
    Lock_fallen();
    unsigned int w,h,b,d;
-   int x,y,xr,yr;
-   Window root,child_return;
+   int x,y;
+   Window root;
+
+   xdo_wait_for_window_map_state(global.xdo,global.SnowWin,IsViewable);
+
+   int rc = XGetGeometry(global.display,global.SnowWin,&root, &x, &y, &w, &h, &b, &d); 
 
-   int rc = XGetGeometry(global.display,global.SnowWin,&root, &x, &y, &w, &h, &b, &d);
    if (rc == 0)
    {
       P("Oeps\n");
@@ -637,20 +838,9 @@ void DisplayDimensions()
       return;
    }
 
-   XTranslateCoordinates(global.display, global.SnowWin, global.Rootwindow, 0, 0, &xr, &yr, &child_return);
-   P("DisplayDimensions: %#lx %#lx x:%d y:%d xr:%d yr:%d w:%d h:%d b:%d d:%d tr:%d\n",global.SnowWin,global.Rootwindow,x,y,xr,yr,w,h,b,d,global.Trans);
-   global.SnowWinX           = xr;// - x;
-   global.SnowWinY           = yr;// - y;
-   if(global.Trans)
-   {
-      global.SnowWinWidth       = global.Wroot - global.SnowWinX;
-      global.SnowWinHeight      = global.Hroot - global.SnowWinY + Flags.OffsetS;
-   }
-   else
-   {
-      global.SnowWinWidth       = w;
-      global.SnowWinHeight      = h + Flags.OffsetS;
-   }
+   global.SnowWinWidth  = w;
+   global.SnowWinHeight = h;
+
    P("DisplayDimensions: SnowWinX: %d Y:%d W:%d H:%d\n",global.SnowWinX,global.SnowWinY,global.SnowWinWidth,global.SnowWinHeight);
 
    global.SnowWinBorderWidth = b;
